eppy.geometry package
=====================

Submodules
----------

eppy.geometry.area\_zone module
-------------------------------

.. automodule:: eppy.geometry.area_zone
   :members:
   :undoc-members:
   :show-inheritance:

eppy.geometry.height\_surface module
------------------------------------

.. automodule:: eppy.geometry.height_surface
   :members:
   :undoc-members:
   :show-inheritance:

eppy.geometry.int2lines module
------------------------------

.. automodule:: eppy.geometry.int2lines
   :members:
   :undoc-members:
   :show-inheritance:

eppy.geometry.mcve module
-------------------------

.. automodule:: eppy.geometry.mcve
   :members:
   :undoc-members:
   :show-inheritance:

eppy.geometry.surface module
----------------------------

.. automodule:: eppy.geometry.surface
   :members:
   :undoc-members:
   :show-inheritance:

eppy.geometry.volume\_zone module
---------------------------------

.. automodule:: eppy.geometry.volume_zone
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: eppy.geometry
   :members:
   :undoc-members:
   :show-inheritance:
